@@ -53,10 +53,13 @@ def get_redis_handler(db_index=0):
     """获取redis连接
     :param db_index: int, redis中数据库索引编号
     """
-    redis_obj = Redis(connection_pool=get_redis_pool(db_index))
-    if redis_obj.ping():
-        return redis_obj
-    else:
+    try:
+        redis_obj = Redis(connection_pool=get_redis_pool(db_index))
+        if redis_obj.ping():
+            return redis_obj
+        else:
+            return None
+    except Exception:
         return None
 
 
